[ostree] Mutable is a keyword in C++11
- From: Colin Walters <walters src gnome org>
- To: commits-list gnome org
- Cc:
- Subject: [ostree] Mutable is a keyword in C++11
- Date: Wed, 23 Sep 2015 12:38:06 +0000 (UTC)
commit c61151d6503e02fd73507784e730facff90b95d8
Author: Leandro Santiago <leandro santiago egym de>
Date: Tue Sep 22 13:52:29 2015 +0200
Mutable is a keyword in C++11
This fix allows including OSTree on C++ projects.
src/libostree/ostree-sysroot-deploy.c | 6 +++---
src/libostree/ostree-sysroot.h | 2 +-
2 files changed, 4 insertions(+), 4 deletions(-)
---
diff --git a/src/libostree/ostree-sysroot.h b/src/libostree/ostree-sysroot.h
index 88cb759..bd3ecea 100644
--- a/src/libostree/ostree-sysroot.h
+++ b/src/libostree/ostree-sysroot.h
@@ -119,7 +119,7 @@ gboolean ostree_sysroot_deploy_tree (OstreeSysroot *self,
gboolean ostree_sysroot_deployment_set_mutable (OstreeSysroot *self,
OstreeDeployment *deployment,
- gboolean mutable,
+ gboolean is_mutable,
GCancellable *cancellable,
GError **error);
[
Date Prev][
Date Next] [
Thread Prev][
Thread Next]
[
Thread Index]
[
Date Index]
[
Author Index]
diff --git a/src/libostree/ostree-sysroot-deploy.c b/src/libostree/ostree-sysroot-deploy.c
index daa8640..3aeee1b 100644
--- a/src/libostree/ostree-sysroot-deploy.c
+++ b/src/libostree/ostree-sysroot-deploy.c
@@ -1960,7 +1960,7 @@ ostree_sysroot_deployment_set_kargs (OstreeSysroot *self,
* ostree_sysroot_deployment_set_mutable:
* @self: Sysroot
* @deployment: A deployment
* @mutable: Whether or not deployment's files can be changed
* @error: Error
*
* By default, deployment directories are not mutable. This function
@@ -1970,7 +1970,7 @@ ostree_sysroot_deployment_set_kargs (OstreeSysroot *self,
gboolean
ostree_sysroot_deployment_set_mutable (OstreeSysroot *self,
OstreeDeployment *deployment,
- gboolean mutable,
+ gboolean is_mutable,
GCancellable *cancellable,
GError **error)
{
@@ -1984,7 +1984,7 @@ ostree_sysroot_deployment_set_mutable (OstreeSysroot *self,
if (!glnx_opendirat (self->sysroot_fd, deployment_path, TRUE, &fd, error))
goto out;
- if (!_ostree_linuxfs_fd_alter_immutable_flag (fd, !mutable, cancellable, error))
+ if (!_ostree_linuxfs_fd_alter_immutable_flag (fd, !is_mutable, cancellable, error))
goto out;
ret = TRUE;
@@ -1960,7 +1960,7 @@ ostree_sysroot_deployment_set_kargs (OstreeSysroot *self,
* @self: Sysroot
* @deployment: A deployment
- * @mutable: Whether or not deployment's files can be changed
+ * @is_mutable: Whether or not deployment's files can be changed
* @error: Error
*